breed [estimators estimator]

globals [MaxView NearView STPDOM ViewAngle MeanDistance MeanVariance AvgTlDistance AvgTlVariance]

turtles-own [win? Dom turn player? opponent Mean_d Var_d energy food win-count avg-energy rounds-dominant]

estimators-own [memory D]

patches-own [food_here?]

;;Setup;;
to setup
  ca
  
  let i 0
  while [i < food_patches]
    [let p_centerx random-pxcor
    let p_centery random-pycor
    ask patches 
      [set food_here? false
       if distancexy p_centerx p_centery <  random 10
         [set food_here? true
          set pcolor violet]
      ]
    set i i + 1
    ]
  

    create-estimators population ;Creates agents that can estimate the dominance scores of their fellow agents
      [set size 2                  ;This allows them to be able to choose not to play a dominance game (see below)
       set color red
       set shape "circle"
       setxy random-xcor random-ycor
       set win? "empty"
       set player? 0
       set Dom 5
       set energy 5
       set i 0
       set memory []
       while [i < population]
         [set memory lput 0 memory
          set i i + 1]
      ]
      
  set NearView 8
  set MaxView 50
  set ViewAngle 120
  set STPDOM 0.5
  do-plots
end
    
to go
  ask turtles [set color red]
  take-turn  ;Hemelrijk indicates that it is necessary to impose a scheduling system on the agents
             ;However, it was unclear whether or not this required a new distribution of turns each round or not.
             ;For this model, agents draw a new turn position each round
  do-measurements
  do-plots
  tick
end

to take-turn
  ask-concurrent turtles
   [set turn (random 5) * population
    ifelse turn > 0
      [ ifelse any? turtles with [opponent != nobody] in-cone NearView ViewAngle
          [set turn (turn - 5)]  ;Like the Hemelrijk model, agents can have their turn position advanced if they see
                               ;agents near them engaging in "attacks"
          [set turn (turn - 1)]
      ]
      [ifelse (energy / 5) < req_energy%
        [seek-food] ;Agents look for food if there energy is below the required energy threshold
        [estimator-go] ;Otherwise they do their dominance competitions
      ]
  ]
end


to seek-food
  if energy < 0 [set energy 0]
  ifelse food = 0
    [ifelse [food_here?] of one-of patches in-cone MaxView ViewAngle = true
       [set food min-one-of (patches in-cone MaxView ViewAngle with [food_here? = true]) [distance myself]
        face food
        fd 1
        ;If agents see food in their view space, they set it as their primary food source and move towards it
       ]
       [ifelse random-float 1 < .5
         [rt SearchAngle]
         [lt SearchAngle]
        fd 1
        set energy energy - metabolism
        if energy < 0 [set energy 0]
        ;Otherwise, they turn around looking for food
       ]
    ]
    [
     ifelse [food_here?] of patch-here = true
       [set energy energy + random 5
        if energy > 5 [set energy 5]
        ;If agents are on food, they eat it
       ] 
       [face food
        fd 1
        set energy energy - metabolism
        if energy < 0 [set energy 0]
        ;Otherwise, they keep moving toward their food
       ]
    ]
end

to estimator-go
  ifelse (count other estimators in-cone PerSpace ViewAngle) > 0
    [set opponent (one-of other estimators in-cone PerSpace ViewAngle)
     estimate
     ;If an agent is in the calling agent's personal space, it estimates its chances of winnning a dominance fight
    ]
    [ifelse (count other estimators in-cone NearView ViewAngle) > 0
      [while [can-move? 1 = false]
        [ifelse random-float 1 < .5
           [rt SearchAngle]
           [lt SearchAngle]
        ]
    
        fd 1
        set energy energy - metabolism
        if energy < 0 [set energy 0]
        ;If there are no agents in the personal space, but there are agents close by, the agent just keep doing what it had been doing before
      ]
      [ifelse (count other estimators in-cone MaxView ViewAngle) > 0
        [face min-one-of other estimators [distance myself]
         while [can-move? 1 = false]
           [ifelse random-float 1 < .5
              [rt SearchAngle]
              [lt SearchAngle]
           ]

            fd 1
            set energy energy - metabolism
            ;If there are no agents near by, but there are some within the maximum view, the agent moves toward the closest one
        ]
        [ifelse random-float 1 < .5
          [rt SearchAngle]
          [lt SearchAngle]
         while [can-move? 1 = false]
           [ifelse random-float 1 < .5
              [rt SearchAngle]
              [lt SearchAngle]
           ]

         fd 1
         set energy energy - metabolism
         ;If there are no visible agents, the agent turns and walks randomly until it finds some 
        ]
      ]
    ]
    
    set size 3 ^ (Dom / 10)
end
      
to estimate
  if Dom < 0.01 [set Dom 0.01]
  
  ask opponent [if Dom < 00.1 [set Dom 0.01]]
  
  ifelse (Dom / (Dom + (item ([who] of opponent) memory))) >= precision random-float 1 2
    [set D (Dom / (Dom + (item ([who] of opponent) memory)))
     ;Agent estimates its chances based on the remembered success of its opponent
      
     ask opponent [set D (Dom / (Dom + (item ([who] of myself) memory)))]
     ;The opponent does the same
   
     ifelse (D / (D + ([D] of opponent))) >= precision random-float 1 2
       [e_win]
       [e_lose]
    ]
    [ifelse random-float 1 < .5
      [rt SearchAngle]
      [lt SearchAngle]
     fd 1
    ]
end

to e_win ;Procedure for evaluating the win condition for the estimators
  set color yellow
  set win? 1
  set Dom (Dom + (win? - D) * STPDOM)
  let energy_stolen (random [energy] of opponent)
  set energy (energy + energy_stolen)
  if energy > 5 [set energy 5]
  if Dom < 0.01 [set Dom 0.01]
  ;Each position in the memory list coresponds to the "who" number of the agent it is storing information for
  ;Thus, item 0 in the memory list is the estimated Dom value for turtle 0.
  ;Rather than storing the actual Dom value that is stored by the agent it self, other agents can only store the
  ;agent's expectency to win. Thus agents can only know how confident othe agents say they are, not how strong they
  ;actually are
  
  ask opponent 
    [set win? 0
     set Dom (Dom - (([win?] of myself) - ([D] of myself)) * STPDOM)
     if Dom < 0.01 [set Dom 0.01]
     set energy (energy - energy_stolen)
     if energy < 0 [set energy 0]
     ;Updates the defending agent's memory as well. 
     set memory (replace-item ([who] of myself) memory (((item ([who] of myself) memory) + ([win?] of myself - [D] of myself )) * STPDOM))
     foreach memory [if ? < 0.01 [set memory replace-item (position ? memory) memory 0.01]]
     ;Losing agents run from the winners
     face myself
     set heading (180 + heading + random 10 - random 10)
     while [can-move? perspace = false ]
       [print 5
         rt random SearchAngle
        lt random SearchAngle]
     while [count (other turtles-on patch-ahead perspace) > 0]
       [ print 6
         rt random SearchAngle
        lt random SearchAngle
       ]
     ;setxy ([pxcor] of patch-ahead perspace) ([pycor] of patch-ahead perspace )
     fd 1
    ]
  
  set memory (replace-item ([who] of opponent) memory (((item ([who] of opponent) memory) - (win? - D)) * STPDOM))
  foreach memory [if ? < 0.01 [set memory replace-item (position ? memory) memory 0.01]]
  ;Winning agents move towards the loser
  face opponent
  while [can-move? 1 = false ]
    [print 7
      rt random SearchAngle
     lt random SearchAngle]
  while [count (other turtles-on patch-ahead 1) > 0 ]
    [print 8
      rt random SearchAngle
     lt random SearchAngle
    ]
  ;setxy ([pxcor] of patch-ahead 1) ([pycor] of patch-ahead 1)
  fd 1
end

to e_lose ;Procedure for evaluating the lose condition for the estimators
  set win? 0
  set Dom (Dom + (win? - D) * STPDOM)
  if Dom < 0.01 [set Dom 0.01]
  
  let energy_stolen (random [energy] of opponent)
  set energy (energy - energy_stolen)
  if energy < 0 [set energy 0]
  
  ask opponent [
    set color yellow
    set win? 1
    set win-count win-count + 1
    set Dom (Dom - (([win?] of myself) - ([D] of myself)) * STPDOM)
    if Dom < 0.01 [set Dom 0.01]
    
    set energy (energy + energy_stolen)
    if energy < 0 [set energy 0]
    if energy > 5 [set energy 5]
    
    set memory (replace-item ([who] of myself) memory ((item ([who] of myself) memory) + ([win?] of myself - [D] of myself )))
    foreach memory [if ? < 0.01 [set memory replace-item (position ? memory) memory 0.01]]
    face myself
    while [can-move? 1 = false ]
      [print 9
        rt random SearchAngle
       lt random SearchAngle]
    while [count (other turtles-on patch-ahead 1) > 0 ]
      [print 10
        rt random SearchAngle
       lt random SearchAngle
      ]
    ;setxy ([pxcor] of patch-ahead 1) ([pycor] of patch-ahead 1)
    fd 1
    set energy energy - metabolism
    if energy < 0 [set energy 0]
    ]
  
  set memory (replace-item ([who] of opponent) memory ((item ([who] of opponent) memory) - (win? - D )))
  foreach memory [if ? < 0.01 [set memory replace-item (position ? memory) memory 0.01]]
  face opponent
  set heading (180 + heading + random 10 - random 10)
  while [can-move? perspace = false ]
    [print 11
      rt random SearchAngle
     lt random SearchAngle]
  while [count (other turtles-on patch-ahead perspace) > 0 ]
    [print 12
      rt random SearchAngle
     lt random SearchAngle
    ]
  fd 1
  set energy energy - metabolism
  if energy < 0 [set energy 0]
end

to do-measurements
  ask turtles [
    let list_t [who] of other turtles
    let list_d [ ]
    foreach list_t [ set list_d lput (precision distance turtle ? 2) list_d]
    set Mean_d mean list_d
    set Var_d variance list_d
  ]
  set MeanDistance mean ([Mean_d] of turtles)
  if ticks > 0
    [set AvgTlDistance (AvgTlDistance * (ticks - 1) + MeanDistance) / ticks]
  ;Mean distance between agents over the whole trial run
  
  if ticks > 0 
   [ask turtles
      [set avg-energy (avg-energy * (ticks - 1) + energy) / ticks]
    ;Mean energy of each agent over the whole trial run
   ]
end

to do-plots
  set-current-plot "Mean Distance"
  set-current-plot-pen "default"
  plot MeanDistance
  
  set-current-plot "Dominance Values"
  let i 0
  while [i < population]
    [ if i = 0 
        [ set-current-plot-pen "Ag0"
          plot [Dom] of turtle 0]
      if i = 1 
        [ set-current-plot-pen "Ag1"
          plot [Dom] of turtle 1]
      if i = 2 
        [ set-current-plot-pen "Ag2"
          plot [Dom] of turtle 2]
      if i = 3 
        [ set-current-plot-pen "Ag3"
          plot [Dom] of turtle 3]
      if i = 4 
        [ set-current-plot-pen "Ag4"
          plot [Dom] of turtle 4]
      if i = 5 
        [ set-current-plot-pen "Ag5"
          plot [Dom] of turtle 5]
      if i = 6 
        [ set-current-plot-pen "Ag6"
          plot [Dom] of turtle 6]
      if i = 7 
        [ set-current-plot-pen "Ag7"
          plot [Dom] of turtle 7]
      if i = 8 
        [ set-current-plot-pen "Ag8"
          plot [Dom] of turtle 8]
      if i = 9 
        [ set-current-plot-pen "Ag9"
          plot [Dom] of turtle 9]
      set i i + 1
    ]
   ask max-one-of turtles [Dom]
     [set rounds-dominant rounds-dominant + 1]
    
  
  set-current-plot "D Values"
  set i 0
  while [i < population]
    [ if i = 0 
        [ set-current-plot-pen "Ag0"
          plot [D] of turtle 0]
      if i = 1 
        [ set-current-plot-pen "Ag1"
          plot [D] of turtle 1]
      if i = 2 
        [ set-current-plot-pen "Ag2"
          plot [D] of turtle 2]
      if i = 3 
        [ set-current-plot-pen "Ag3"
          plot [D] of turtle 3]
      if i = 4 
        [ set-current-plot-pen "Ag4"
          plot [D] of turtle 4]
      if i = 5 
        [ set-current-plot-pen "Ag5"
          plot [D] of turtle 5]
      if i = 6 
        [ set-current-plot-pen "Ag6"
          plot [D] of turtle 6]
      if i = 7 
        [ set-current-plot-pen "Ag7"
          plot [D] of turtle 7]
      if i = 8 
        [ set-current-plot-pen "Ag8"
          plot [D] of turtle 8]
      if i = 9 
        [ set-current-plot-pen "Ag9"
          plot [D] of turtle 9]
      set i i + 1
    ]
  
  
  set-current-plot "Energy Plot"
  clear-plot
  set i 0
  while [i < population]
    [
      if i = 0 
        [ set-current-plot-pen "Ag0"
          plotxy [who] of turtle 0 [energy] of turtle 0]
      if i = 1 
        [ set-current-plot-pen "Ag1"
          plotxy [who] of turtle 1 [energy] of turtle 1]
      if i = 2 
        [ set-current-plot-pen "Ag2"
          plotxy [who] of turtle 2 [energy] of turtle 2]
      if i = 3 
        [ set-current-plot-pen "Ag3"
          plotxy [who] of turtle 3 [energy] of turtle 3]
      if i = 4 
        [ set-current-plot-pen "Ag4"
          plotxy [who] of turtle 4 [energy] of turtle 4]
      if i = 5 
        [ set-current-plot-pen "Ag5"
          plotxy [who] of turtle 5 [energy] of turtle 5]
      if i = 6 
        [ set-current-plot-pen "Ag6"
          plotxy [who] of turtle 6 [energy] of turtle 6]
      if i = 7 
        [ set-current-plot-pen "Ag7"
          plotxy [who] of turtle 7 [energy] of turtle 7]
      if i = 8 
        [ set-current-plot-pen "Ag8"
          plotxy [who] of turtle 8 [energy] of turtle 8]
      if i = 9 
        [ set-current-plot-pen "Ag9"
          plotxy [who] of turtle 9 [energy] of turtle 9]
      set i i + 1
    ]
  
end

@#$#@#$#@
GRAPHICS-WINDOW
187
10
647
491
50
50
4.46
1
10
1
1
1
0
1
1
1
-50
50
-50
50
0
0
1
ticks

SLIDER
14
91
186
124
food_patches
food_patches
0
20
5
1
1
NIL
HORIZONTAL

SLIDER
14
124
186
157
population
population
0
50
8
1
1
NIL
HORIZONTAL

SLIDER
14
157
186
190
req_energy%
req_energy%
0
1
0.2
0.01
1
NIL
HORIZONTAL

SLIDER
14
189
186
222
metabolism
metabolism
0
1
0.01
0.01
1
NIL
HORIZONTAL

SLIDER
14
222
186
255
SearchAngle
SearchAngle
0
180
90
1
1
NIL
HORIZONTAL

SLIDER
14
255
186
288
PerSpace
PerSpace
0
10
4
1
1
NIL
HORIZONTAL

BUTTON
18
27
84
60
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
85
27
148
60
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

PLOT
649
10
849
160
Mean Distance
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
649
160
1003
371
Dominance Values
NIL
NIL
0.0
10.0
0.0
10.0
true
true
PENS
"Ag0" 1.0 0 -16777216 true
"Ag1" 1.0 0 -5825686 true
"Ag2" 1.0 0 -8630108 true
"Ag3" 1.0 0 -13791810 true
"Ag4" 1.0 0 -13840069 true
"Ag5" 1.0 0 -1184463 true
"Ag6" 1.0 0 -6459832 true
"Ag7" 1.0 0 -955883 true
"Ag8" 1.0 0 -2674135 true
"Ag9" 1.0 0 -7500403 true

PLOT
649
371
1003
576
D Values
NIL
NIL
0.0
10.0
0.0
2.0
true
true
PENS
"Ag0" 1.0 0 -16777216 true
"Ag1" 1.0 0 -5825686 true
"Ag2" 1.0 0 -8630108 true
"Ag3" 1.0 0 -13791810 true
"Ag4" 1.0 0 -13840069 true
"Ag5" 1.0 0 -1184463 true
"Ag6" 1.0 0 -6459832 true
"Ag7" 1.0 0 -955883 true
"Ag8" 1.0 0 -2674135 true
"Ag9" 1.0 0 -7500403 true

PLOT
849
10
1049
160
Energy Plot
NIL
NIL
0.0
10.0
0.0
10.0
true
false
PENS
"Ag0" 1.0 1 -16777216 true
"Ag1" 1.0 1 -16777216 true
"Ag2" 1.0 1 -16777216 true
"Ag3" 1.0 1 -16777216 true
"Ag4" 1.0 1 -16777216 true
"Ag5" 1.0 1 -16777216 true
"Ag6" 1.0 1 -16777216 true
"Ag7" 1.0 1 -16777216 true
"Ag8" 1.0 1 -16777216 true
"Ag9" 1.0 1 -16777216 true

@#$#@#$#@
PURPOSE
-------
	The purpose of this model is to understand how the dynamic interactions of dominance competitions in simple agent groups that lead to the more complex behavior of reciprocity may affect the emergence of other complex social behaviors involved in food seeking.

STATE VARIALBLES AND SCALES
---------------------------
	The model space is divided into agents that interact with one another, and the environment which includes patches of food. Agents in the model are based on estimators from Hemelrijk (1996). Estimators are called such because they compete with other agents around them for dominance based on how well they estimate they will do. Thus, dominance competitions are the result of perceived dominance values. These estimators have a true dominance scores which indicate the true out come of their collective dominance interactions, given as Dom. Estimators also have a perceived dominance score given as D, which is the chance of that particular estimator to win in a dominance competition with a different agent, based on the estimator's memory of previous interactions with that agent. This memory comes is stored as the list memory. The final important variable at this level is the personal space parameter PerSpace which indicates how close an estimator will allow other agents to come before it initiates a dominance competition. These variables and parameters define the basic interactions between estimators in the model space. 

	Because the model is primarily a dominance competition model, these variables constitute the framework from which we can observe the emergent of social behavior. Based on this, agents are characterized by the state variables: identity number, estimator (in the original Hemelrijk (1996) there were two breeds of agents, but one was dropped for this experiment), dominance level and perceived dominance success. Agents' size reflects their dominance level, but this is purely for visualization purposes and doesn't effect the model beyond what is already defined by the mathematics of the dominance competitions.

	In the model extension that was conducted by this experiment, agents were given two additional state variable, which was their energy level, given by energy. This defined how much energy an agent could lose in a dominance competition, and how long before an agent needed to stop competing and go look for food. With this, agents were given a metabolism rate, which was defined as the rate by which they used energy while engaging in the usual tasks of their lives. This was standardized across all agents and was generally applied to the task of moving around.

	A second hierarchical level of community was loosely defined. This was simply the aggregate of all the agents in the model space, which usually consisted of either four or eight agents. This community was measured by the average distance between members at any given point in time. The spatial structure of the community was an emergent property of the dominance interactions of the agents (described originally by Hemelrijk (1996) ).
	Finally, patches were defined by a simple binary variable that indicated whether they had a food resource on their patch or not. Food resources were not eliminated upon consumption, but persisted. This developed the environment into one or several food rich areas, with barren areas inbetween.

SCHEDULING
----------
	Scheduling was one of the most important part of the original Hemelrijk model, and the timing regime was implemented here. The basic definition of the timing regime was a turn-based system where each agent executed its own turn before the others. This was an important time regime because it created a line of agents waiting to take an action, but also made it possible to define a means by which an agent could move up in line if it met some specific condition. This condition was whether or not an agent was in viewing distance of a pair of agents that were currently competing. If an agent saw other agents engaging in a dominance competition, it would move its position to the front of the line and take its turn next.

	Once its turn began, an agent would first determine if its energy levels were below a global threshold defined as the starvation rate. If this was true, the agent would initiate a food seeking behavior, where it would move the the closest patch containing food and eat. This food seeking behavior continued until the agent increased its energy levels above the threshold, meaning that the estimator that was seeking food would not initiate a dominance interaction until it had eaten.

	If the estimators level was not below the threshold, then the agent would follow a behavioral path wherein it would seek to be close to the main aggregate of agents, and if any other agents were within its defined personal space, it would initiate a dominance competition. When agents successfully won a dominance competition, they pursued the lose by moving one step after them. In turn, losers of dominance competitions would move away one step. 

DESIGN CONCEPTS
---------------
EMERGENCE: The most easily observable emergent behavior within the community of agents was the spatial configuration of the group as it came together. While group formation was ordained by a programmed behavior of searching for other agents, there was not instruction as to the structure of these groups. However, Hemelrijk found, and I was able to reproduce, a structure emerging wherein more dominant agents made up the spatial center of the group, and agents with less dominance existed on the periphery. With food requirements lending their pressures to the structure, this developed into a king-of-the-hill type of scenario where agents could be observed to compete over access to the resources in the environment. Dominant agents could be seen to take up positions at the center of food clusters, while less dominant agents existed on the periphery, having to risk being attacked in order to gain some food. 

	On some trials, agents could also be observed to occasionally form small splinter groups, or even completely divergent social communities. The latter was rare, and both depended on the initial starting position of the agents, the size of the model space and the location of the food clusters. If enough agents located each other away from they larger group, there was no need to seek larger group inclusion, and the splinter cell would exist on a separate food cluster. This emergent property was only observed qualitatively and was not analyzed.

PREDICTION: Estimators were able to predict their future success on a dominance competition based on a stored memory of their previous encounter with a particular agent. Estimators kept a list, where position of an item in the list coincided with the ID of the individual encountered, and the value of the item was the D value presented in the last dominance competition with that individual. The D value is the perceived dominance of that particular agent, so each estimator at any given time only knows how good the other estimators feel about themselves, not their true levels of dominance. This was established in Hemelrijk (1996).

SENSING: The ability to know their opponents D scores is the primary sense of the estimators as well. Based on this previous knowledge, estimators actually decide whether or not they want to engage in a dominance competition. This takes the form of an internal dominance competition, where the estimator competes against its memory of its opponent's success. If the outcome of this internal competition is negative, the estimator will simply walk away and avoid an interaction.
	Agents also sense their energy levels and use these to determine whether they can afford to be in a dominance interaction or whether they avoid interactions and search for food.


INTERACTION: Agents interact with other agents entirely through dominance competitions. However, in this model the dominance competition does not only ascertain the rank of the individual, it is also the primary mover of energy resources within the community of agents. When an agent wins a dominance interaction, its dominance level increases, proportional to the difference between its previous rank and the rank of its opponent. Thus beating an agent higher on the hierarchical scale then yourself will get you more dominance than beating one lower. The same procedure works in reverse for losers. Additionally, winning and losing confer resource gains and losses respectively. When an agent wins it effectively takes some of the losers energy and adds it to its own energy reserves. This was based on the idea that a real world dominance competition might involve the taking of food, or some other energy cost to the loser.

OBSERVATION: For this particular analysis, data is best collected at each individual time step so that the evolution of the hierarchical levels, distances between agents and changes in energy levels can be observed as a function of the time spent within the community for each individual agent. It is for this reason that a dynamical analysis is recommended. However, this researcher currently lacks the tools necessary to conduct the rigorous mathematical analysis required by dynamics so the average distance between agents was recorded. However model plots show the trends and changes over time qualitatively.

INITIALIZATION
--------------
	The Hemelrijk's original model used a model space of 200 x 200 patches. However, in replication, it was found that the patterns that were supposed to be emerging were more difficult to observe when the space between agents was so great. Mainly, agents were having a difficult time locating one another since the population levels were fairly low (4 or 8). For this reason, the model space was reduced to 100 x 100 patches for this paper, a change which is supported by Hemelrijk in a later version of the model.
	Location of patches with food in the environment are generated semi-randomly. This initial sprouting location is random, but once a sprouting location is determined, all patches within a certain radius have a random probability of also sprouting food. Thus the food clusters are small circular areas of patches, many of which will contain food. Agent starting position is also random upon initialization. Agents begin with a medium Dom value (5) and no preconceived notions of their success (D values are initialized at 0).  The memory list is initialized as an empty list whose length is equal to the number of agents defined by the population parameter. Agents are initialized with three different viewing specifications, a near view distance set to 8 units, a maximum view distance set to 50, and a viewing angle set to 120. Finally, energy levels are initialized to their maximum (in this case 5). 

INPUT
-----
	The energy levels gained and lost throughout interactions are defined based on a random chance distribution. Dominance levels presented and gained or lost are dependent on previous experience with the opponent and the opponents dominance rank.


HOW TO USE IT
-------------
SearchAngle, PerSpace and req_energy% are the three primary parameters that affect the spatial and behavioral makeup of the agents. These change energy and doinance requirements for the agents.


CREDITS AND REFERENCES
----------------------
Grimm, V., Revilla, E., Berger, U., Jeltsch, F., Mooij, W. M., Railsback, S. F., Thulke, H. H., et al. (2005). Pattern-oriented modeling of agent-based complex systems: lessons from ecology. Science, 310(5750), 987.

Hemelrijk, C. (1990). A matrix partial correlation test used in invetigation sof reciprocity and other social interaction patterns at group level. Journal of Theoretical Biology, 143, 405-420.

Hemelrijk, C. (1996). Dominance interactions, spatial dynamics and emergent reciprocity in a virtual world. From animals to animats 4: Proceedings of the Fourth International Conference on Simulation of Adaptive Behavior, 4.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 4.1.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Exp1-Clustered-EndResults1" repetitions="40" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="10000"/>
    <metric>AvgTlDistance</metric>
    <metric>AvgTlVariance</metric>
    <metric>[win-count] of turtle 0</metric>
    <metric>[win-count] of turtle 1</metric>
    <metric>[win-count] of turtle 2</metric>
    <metric>[win-count] of turtle 3</metric>
    <metric>[win-count] of turtle 4</metric>
    <metric>[win-count] of turtle 5</metric>
    <metric>[win-count] of turtle 6</metric>
    <metric>[win-count] of turtle 7</metric>
    <metric>[precision avg-energy 2] of turtle 0</metric>
    <metric>[precision avg-energy 2] of turtle 1</metric>
    <metric>[precision avg-energy 2] of turtle 2</metric>
    <metric>[precision avg-energy 2] of turtle 3</metric>
    <metric>[precision avg-energy 2] of turtle 4</metric>
    <metric>[precision avg-energy 2] of turtle 5</metric>
    <metric>[precision avg-energy 2] of turtle 6</metric>
    <metric>[precision avg-energy 2] of turtle 7</metric>
    <metric>[rounds-dominant] of turtle 0</metric>
    <metric>[rounds-dominant] of turtle 1</metric>
    <metric>[rounds-dominant] of turtle 2</metric>
    <metric>[rounds-dominant] of turtle 3</metric>
    <metric>[rounds-dominant] of turtle 4</metric>
    <metric>[rounds-dominant] of turtle 5</metric>
    <metric>[rounds-dominant] of turtle 6</metric>
    <metric>[rounds-dominant] of turtle 7</metric>
    <enumeratedValueSet variable="food_patches">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="metabolism">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="PerSpace">
      <value value="2"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="req_energy%">
      <value value="0.2"/>
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SearchAngle">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="population">
      <value value="8"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
